package reportinEngines;


import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.PrintWriter;

import java.util.ArrayList;

import dataModel.Dish;
import dataModel.Employee;

/**
* <h1>ReportGeneratorForFiles</h1>
* Responsible for saving the restaurant statistics 
* in plain text format
*
* @version 1.0
* @since   2017-07-22
*/
public class ReportGeneratorForFiles implements IReportGenerator {

	/**
 	 * Saves the statistics for the employees
 	 * 
 	 * @param personnel: list of employees
 	 */
	@Override
	public void reportOnEmps(ArrayList<Employee> personnel){

		PrintWriter outputStream = null;
		String outputFileName = "./output/empReport.ascii";

		//Opening files for read and write, checking exception
		try {
			outputStream = new PrintWriter(new FileOutputStream(outputFileName));
		} catch (FileNotFoundException e) {
			System.out.println("Problem opening Emp report.");
			System.exit(0);
		}

		for(Employee e: personnel){
			outputStream.println(e.getShortReport());
		}
		
		outputStream.close();
		return;
	}
	
	/**
 	 * Saves the statistics for the dishes
 	 * 
 	 * @param menu: list of dishes
 	 */
	@Override
	public void reportOnDishes(ArrayList<Dish> menu){

		PrintWriter outputStream = null;
		String outputFileName = "./output/dishReport.ascii";

		//Opening files for read and write, checking exception
		try {
			outputStream = new PrintWriter(new FileOutputStream(outputFileName));
		} catch (FileNotFoundException e) {
			System.out.println("Problem opening Dish report.");
			System.exit(0);
		}

		for(Dish d: menu){
			outputStream.println(d.getShortReport());
		}
		
		outputStream.close();
		return;
	}

}
